@@ -270,7 +270,36 @@ static int encoder_check_audio_sample_fmt(AVCodec *codec, enum AVSampleFormat sa
 	}
 	return 0;
 }
+/*
+ * check that a given sample rate is supported by the encoder
+ * args:
+ *    codec - pointer to AVCodec
+ *    sample_rate - audio sample rate
+ *
+ * assertions:
+ *    none
+ *
+ * returns: sample_rate if supported or max supported sample rate if not
+ */
+static int select_sample_rate(const AVCodec *codec, int sample_rate)
+{
+	const int *p;
+ 	int best_samplerate = 0;
 
+	if (!codec->supported_samplerates)
+		return sample_rate;
+
+	p = codec->supported_samplerates;
+	while (*p) 
+	{
+		if (*p == sample_rate)
+			return sample_rate;
+
+		best_samplerate = FFMAX(*p, best_samplerate);
+		p++;
+    }
+	return best_samplerate;
+}
 /*
  * video encoder initialization for raw input
  *  (don't set a codec but set the proper codec 4cc)
@@ -748,6 +777,15 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 
 	audio_codec_data->codec_context->codec_type = AVMEDIA_TYPE_AUDIO;
 
+    int best_samprate = select_sample_rate(audio_codec_data->codec, encoder_ctx->audio_samprate);
+
+	if(best_samprate != encoder_ctx->audio_samprate)
+	{
+		fprintf(stderr, "ENCODER: audio codec doesn't support sample rate = %i (best is %i)\n", 
+			encoder_ctx->audio_samprate, best_samprate);
+		encoder_ctx->audio_samprate = best_samprate;
+	}
+     
 	audio_codec_data->codec_context->time_base = (AVRational){1, encoder_ctx->audio_samprate};
 
 	/*check if codec supports sample format*/
@@ -894,7 +932,7 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
 
 	audio_codec_data->frame->nb_samples = frame_size;
 	audio_codec_data->frame->format = audio_defaults->sample_format;
-
+audio_codec_data->frame->channels = audio_codec_data->codec_context->channels;
 	audio_codec_data->frame->channel_layout = audio_codec_data->codec_context->channel_layout;
 
 	/*set codec data in encoder context*/
@@ -1274,7 +1312,7 @@ int encoder_process_next_video_buffer(encoder_context_t *encoder_ctx)
 	__UNLOCK_MUTEX ( __PMUTEX );
 
 
-	encoder_write_video_data(encoder_ctx);
+	//encoder_write_video_data(encoder_ctx);
 
 	return 0;
 }
@@ -1323,12 +1361,12 @@ int encoder_flush_video_buffer(encoder_context_t *encoder_ctx)
 	flushed_frame_counter = 0;
 	encoder_ctx->enc_video_ctx->flush_delayed_frames  = 1;
 
-	while(!encoder_ctx->enc_video_ctx->flush_done)
-	{
+	// while(!encoder_ctx->enc_video_ctx->flush_done)
+	// {
 		encoder_encode_video(encoder_ctx, NULL);
-		encoder_write_video_data(encoder_ctx);
-		flushed_frame_counter++;
-	}
+	// 	encoder_write_video_data(encoder_ctx);
+	// 	flushed_frame_counter++;
+	// }
 
 	if(verbosity > 1)
 		printf("ENCODER: flushed %i delayed video frames\n", flushed_frame_counter);
@@ -1361,12 +1399,12 @@ int encoder_flush_audio_buffer(encoder_context_t *encoder_ctx)
 	int flushed_frame_counter = 0;
 	encoder_ctx->enc_audio_ctx->flush_delayed_frames  = 1;
 
-	while(!encoder_ctx->enc_audio_ctx->flush_done)
-	{
+	// while(!encoder_ctx->enc_audio_ctx->flush_done)
+	// {
 		encoder_encode_audio(encoder_ctx, NULL);
-		encoder_write_audio_data(encoder_ctx);
-		flushed_frame_counter++;
-	}
+	// 	encoder_write_audio_data(encoder_ctx);
+	// 	flushed_frame_counter++;
+	// }
 
 	if(verbosity > 1)
 		printf("ENCODER: flushed %i delayed audio frames\n", flushed_frame_counter);
@@ -1394,11 +1432,11 @@ int encoder_process_audio_buffer(encoder_context_t *encoder_ctx, void *data)
 		encoder_ctx->audio_channels <= 0)
 		return -1;
 
-	encoder_encode_audio(encoder_ctx, data);
+	return encoder_encode_audio(encoder_ctx, data);
 
-	int ret = encoder_write_audio_data(encoder_ctx);
+	// int ret = encoder_write_audio_data(encoder_ctx);
 
-	return ret;
+	// return ret;
 }
 
 /*
@@ -1494,32 +1532,78 @@ static int read_video_df_pts(encoder_video_context_t *enc_video_ctx)
 	return enc_video_ctx->read_df;
 }
 
-
-static int libav_encode(AVCodecContext *avctx, AVPacket *pkt, AVFrame *frame, int *got_packet)
+static int libav_send_encode(AVCodecContext *avctx, AVFrame *frame)
 {
 	int ret;
 
-  *got_packet = 0;
-
+    if (!getLoadLibsInstance()->m_avcodec_is_open(avctx))
+		fprintf(stderr, "ENCODER: codec not opened\n"); 
+    if(!getLoadLibsInstance()->m_av_codec_is_encoder(avctx->codec))
+		fprintf(stderr, "ENCODER: codec not an encoder\n");
+ 
 	if(frame)
-    {
-        ret = getLoadLibsInstance()->m_avcodec_send_frame(avctx, frame);
-        if (ret < 0)
-            return ret; //if (ret == AVERROR(EAGAIN)) //input buffer is full
-    }
+	{
 
-  ret = getLoadLibsInstance()->m_avcodec_receive_packet(avctx, pkt);
-  char str[50];
-  sprintf(str,"avcode_receive_packet of ret=%d",ret);
-  //cheese_print_log(str);
-  if (!ret)
-  	*got_packet = 1;
-  if (ret == AVERROR(EAGAIN)) //output buffer is empty
-  	return 0;
+		if (avctx->codec_type == AVMEDIA_TYPE_AUDIO && frame->nb_samples != avctx->frame_size) 
+			fprintf(stderr, "ENCODER: audio samples differ from frame size\n");
+		if (avctx->codec_type == AVMEDIA_TYPE_AUDIO && frame->channels <= 0)
+		{ 
+			fprintf(stderr, "ENCODER: no audio channels set in frame\n");
+			frame->channels = avctx->channels;
+		}
+        ret = getLoadLibsInstance()->m_avcodec_send_frame(avctx, frame);
+  		if (ret < 0)
+		{
+        //	fprintf(stderr, "ENCODER: avcodec_send_frame error (%i): %s\n", ret, av_err2str(ret));
+  			return ret; //if (ret == AVERROR(EAGAIN)) //input buffer is full
+		}
+	}
+	else
+	{
+		//flush encode buffers
+        getLoadLibsInstance()->m_avcodec_send_frame(avctx, NULL);
+	}
+	
 
   return ret;
 }
 
+static int libav_get_encode(AVCodecContext *avctx, AVPacket *pkt, int* got_packet)
+{
+	int ret = 0;
+	*got_packet = 0;
+
+    ret = getLoadLibsInstance()->m_avcodec_receive_packet(avctx, pkt);
+	if (!ret)
+  		*got_packet = 1;
+
+	return ret;
+}
+// static int libav_encode(AVCodecContext *avctx, AVPacket *pkt, AVFrame *frame, int *got_packet)
+// {
+// 	int ret;
+
+//   *got_packet = 0;
+
+// 	if(frame)
+//     {
+//         ret = getLoadLibsInstance()->m_avcodec_send_frame(avctx, frame);
+//         if (ret < 0)
+//             return ret; //if (ret == AVERROR(EAGAIN)) //input buffer is full
+//     }
+
+//   ret = getLoadLibsInstance()->m_avcodec_receive_packet(avctx, pkt);
+//   char str[50];
+//   sprintf(str,"avcode_receive_packet of ret=%d",ret);
+//   //cheese_print_log(str);
+//   if (!ret)
+//   	*got_packet = 1;
+//   if (ret == AVERROR(EAGAIN)) //output buffer is empty
+//   	return 0;
+
+//   return ret;
+// }
+
 /*
  * encode video frame
  * args:
@@ -1626,29 +1710,25 @@ int encoder_encode_video(encoder_context_t *encoder_ctx, void *input_frame)
 	//	av_log(avctx, AV_LOG_ERROR, "buffer smaller than minimum size\n");
     //    return -1;
     //}
- 	if(!enc_video_ctx->flush_delayed_frames)
-    	ret = libav_encode(
+ 		ret = libav_send_encode(
 			video_codec_data->codec_context,
-			pkt,
-			video_codec_data->frame,
-			&got_packet);
-   	else
-   		ret = libav_encode(
-			video_codec_data->codec_context,
-			pkt, NULL, /*NULL flushes the encoder buffers*/
-			&got_packet);
-
+			video_codec_data->frame);
+	
 	if(ret < 0)
 	{
 		fprintf(stderr, "ENCODER: Error encoding video frame: %i\n", ret);
 		return ret;
 	}
 
-    char str_gotpacket[30];
-    sprintf(str_gotpacket,"ret = %d, gotpacket = %d\n",ret, got_packet);
-    //cheese_print_log(str_gotpacket);
+	if(enc_video_ctx->flush_delayed_frames)
+	{
+		if(!enc_video_ctx->flushed_buffers)
+            getLoadLibsInstance()->m_avcodec_flush_buffers(video_codec_data->codec_context);
+		
+		enc_video_ctx->flushed_buffers = 1;
+	}
 
-	if(got_packet)
+	while (libav_get_encode(video_codec_data->codec_context, pkt, &got_packet) >= 0)
 	{
 		//if(pkt.pts != AV_NOPTS_VALUE)
 		//	printf("ENCODER: (video) pts:%" PRId64 " dts:%" PRId64 "\n", pkt.pts, pkt.dts);
@@ -1675,7 +1755,7 @@ int encoder_encode_video(encoder_context_t *encoder_ctx, void *input_frame)
     	outsize = pkt->size;
 
             getLoadLibsInstance()->m_av_packet_unref(pkt);
-    }
+    //}
 
 	if(enc_video_ctx->flush_delayed_frames && ((outsize == 0) || !got_packet))
     	enc_video_ctx->flush_done = 1;
@@ -1687,6 +1767,8 @@ int encoder_encode_video(encoder_context_t *encoder_ctx, void *input_frame)
 	last_video_pts = enc_video_ctx->pts;
 
 	encoder_ctx->enc_video_ctx->outbuf_coded_size = outsize;
+		encoder_write_video_data(encoder_ctx);
+	}
 	return (outsize);
 #endif
 }
@@ -1726,16 +1808,54 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 
 	encoder_codec_data_t *audio_codec_data = (encoder_codec_data_t *) enc_audio_ctx->codec_data;
 
-	if(enc_audio_ctx->flush_delayed_frames)
+
+
+	/*PCM output: no need for encoding - save samples directly to outbuf*/
+	if(audio_codec_data->codec_context->codec_id == AV_CODEC_ID_PCM_F32LE)
 	{
-		//pkt.size = 0;
-		if(!enc_audio_ctx->flushed_buffers)
+		if(enc_audio_ctx->flush_delayed_frames)
 		{
-			if(audio_codec_data)
-                getLoadLibsInstance()->m_avcodec_flush_buffers(audio_codec_data->codec_context);
+			/*since we are not encoding we don't have to flush the encoder buffers*/
 			enc_audio_ctx->flushed_buffers = 1;
+			enc_audio_ctx->flush_done = 1;
 		}
- 	}
+ 	
+		if (audio_data == NULL)
+		{
+			enc_audio_ctx->outbuf_coded_size = outsize;
+			return outsize;
+		}
+
+		int align = 0;
+
+        int buffer_size = getAvutil()->m_av_samples_get_buffer_size(
+			NULL,
+			audio_codec_data->codec_context->channels,
+			audio_codec_data->codec_context->frame_size,
+			audio_codec_data->codec_context->sample_fmt,
+			align);
+
+		if(buffer_size <= 0)
+		{
+			fprintf(stderr, "ENCODER: (encoder_encode_audio) PCM av_samples_get_buffer_size error (%d): chan(%d) nb_samp(%d) samp_fmt(%d)\n",
+				buffer_size,
+				audio_codec_data->codec_context->channels,
+				audio_codec_data->codec_context->frame_size,
+				audio_codec_data->codec_context->sample_fmt);
+
+			return outsize;
+		}
+
+		memcpy(enc_audio_ctx->outbuf, audio_data, buffer_size);
+		enc_audio_ctx->duration = (audio_codec_data->codec_context->time_base.num*1000/audio_codec_data->codec_context->time_base.den) * 90;
+		enc_audio_ctx->pts += enc_audio_ctx->duration;
+		enc_audio_ctx->dts = enc_audio_ctx->pts;
+		enc_audio_ctx->flags = 0;
+		enc_audio_ctx->outbuf_coded_size = buffer_size;
+
+		outsize = buffer_size;
+		return outsize;
+	}
 
 	/* encode the audio */
 	/* encode the video */
@@ -1791,6 +1911,11 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 			return outsize;
 		}
 
+		if(audio_codec_data->frame->nb_samples != audio_codec_data->codec_context->frame_size)
+		{
+			fprintf(stderr, "ENCODER: audio frame->nb_samples(%i) != codec_context->frame_size(%i)", 
+				audio_codec_data->frame->nb_samples, audio_codec_data->codec_context->frame_size);
+		}
 		if(!enc_audio_ctx->monotonic_pts) /*generate a real pts based on the frame timestamp*/
 			audio_codec_data->frame->pts += ((enc_audio_ctx->pts - last_audio_pts)/1000) * 90;
 		else  if (audio_codec_data->codec_context->time_base.den > 0) /*generate a true monotonic pts based on the codec fps*/
@@ -1801,23 +1926,18 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 			fprintf(stderr, "ENCODER: (encoder_encode_audio) couldn't generate a monotonic ts: time_base.den(%d)\n",
 				 audio_codec_data->codec_context->time_base.den);
 		}
-
-		ret = libav_encode(
-				audio_codec_data->codec_context,
-				pkt,
-				audio_codec_data->frame,
-				&got_packet);
 	}
-	else
+    ret = libav_send_encode(
+                audio_codec_data->codec_context,
+                audio_codec_data->frame);
+	if(!enc_audio_ctx->flushed_buffers)
 	{
-		ret = libav_encode(
-			audio_codec_data->codec_context,
-			pkt,
-			NULL, /*NULL flushes the encoder buffers*/
-			&got_packet);
+		if(audio_codec_data)
+            getLoadLibsInstance()->m_avcodec_flush_buffers(audio_codec_data->codec_context);
+		enc_audio_ctx->flushed_buffers = 1;
 	}
 
-	if(got_packet)
+	while (libav_get_encode(audio_codec_data->codec_context, pkt, &got_packet) >= 0)
 	{
 		//if(pkt.pts != AV_NOPTS_VALUE)
 		//	printf("ENCODER: (audio) pts:%" PRId64 " dts:%" PRId64 "\n", pkt.pts, pkt.dts);
@@ -1845,14 +1965,16 @@ int encoder_encode_audio(encoder_context_t *encoder_ctx, void *audio_data)
 		outsize = pkt->size;
 		
         getLoadLibsInstance()->m_av_packet_unref(pkt);
-	}
 
 	last_audio_pts = enc_audio_ctx->pts;
 
-	if(enc_audio_ctx->flush_delayed_frames && ((outsize == 0) || !got_packet))
-    	enc_audio_ctx->flush_done = 1;
+		if(enc_audio_ctx->flush_delayed_frames && outsize == 0)
+    		enc_audio_ctx->flush_done = 1;
 
-	enc_audio_ctx->outbuf_coded_size = outsize;
+		enc_audio_ctx->outbuf_coded_size = outsize;
+
+		encoder_write_audio_data(encoder_ctx);
+	}
 	return (outsize);
 #endif
 }
