@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* Maintainer: shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef LOAD_LIBS_H
 #define LOAD_LIBS_H
@@ -92,7 +76,8 @@ typedef void (*uos_swr_free)(struct SwrContext **s);
 //lswscale
 //void sws_freeContext(struct SwsContext *swsContext);
 typedef void (*uos_sws_freeContext)(struct SwsContext *swsContext);
-
+typedef int (*uos_avcodec_is_open)(AVCodecContext *s);
+typedef int (*uos_av_codec_is_encoder)( AVCodec *codec);
 typedef struct _LoadLibNames {
     char *chAvcodec;
     char *chFfmpegthumbnailer;
@@ -132,6 +117,8 @@ typedef struct _LoadLibs {
     uos_av_init_packet m_av_init_packet;
     uos_av_packet_alloc m_av_packet_alloc;
 
+    uos_av_codec_is_encoder m_av_codec_is_encoder;
+    uos_avcodec_is_open m_avcodec_is_open;
 
     uos_video_thumbnailer m_video_thumbnailer;
     uos_video_thumbnailer_destroy m_video_thumbnailer_destroy;
