@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* Maintainer: shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainwindow.h"
 #include "capplication.h"
@@ -31,6 +15,8 @@
 #include "switchcamerabtn.h"
 #include "windowstatethread.h"
 #include "camera.h"
+#include "eventlogutils.h"
+#include "config.h"
 
 #include <DLabel>
 #include <DApplication>
@@ -1265,6 +1251,14 @@ void CMainWindow::loadAfterShow()
     showChildWidget();
     m_windowStateThread = new windowStateThread(this);
     connect(m_windowStateThread, &windowStateThread::someWindowFullScreen, this, &CMainWindow::onStopPhotoAndRecord);
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"mode", 1},
+        {"version", VERSION},
+        {"camera_connected", DataManager::instance()->getdevStatus() ? true : false}
+    };
+    EventLogUtils::get().writeLogs(obj);
 }
 
 void CMainWindow::updateBlockSystem(bool bTrue)
@@ -1459,6 +1453,14 @@ void CMainWindow::onModeSwitchBoxValueChanged(int type)
 
 void CMainWindow::onPhotoRecordBtnClked()
 {
+    QJsonObject obj {
+        {"tid", m_photoRecordBtn->photoState() ? EventLogUtils::StartPhoto : EventLogUtils::StartRecording},
+        {"version", VERSION},
+        {"camera_connected", DataManager::instance()->getdevStatus() ? true : false}
+    };
+    if(!m_bRecording)
+        EventLogUtils::get().writeLogs(obj);
+
     //没有摄像机，不进行任何操作
     if (NOCAM == DataManager::instance()->getdevStatus()) {
         return;
@@ -2287,6 +2289,7 @@ void CMainWindow::showChildWidget()
         showWidget(m_modeSwitchBox, false);
         showWidget(m_takePhotoSettingArea, false);
         showWidget(m_photoRecordBtn, true);
+        showWidget(m_filterName, false);
         return;
     }
     if (m_bRecording) {  //正在录像
@@ -2302,6 +2305,7 @@ void CMainWindow::showChildWidget()
     showWidget(m_modeSwitchBox, true);
     showWidget(m_photoRecordBtn, true);
     showWidget(m_takePhotoSettingArea, true);
+    showWidget(m_filterName, m_bShowFilterName);
 }
 
 void CMainWindow::showWidget(DWidget *widget, bool bShow)
