@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* Maintainer: shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "majorimageprocessingthread.h"
 #include "datamanager.h"
@@ -59,6 +43,8 @@ void MajorImageProcessingThread::init()
     m_bTake = false;
     m_videoDevice = nullptr;
     m_result = -1;
+    m_nCount = 0;
+    m_firstPts = 0;
 }
 
 void MajorImageProcessingThread::setFilter(QString filter)
@@ -71,6 +57,11 @@ void MajorImageProcessingThread::setExposure(int exposure)
     m_exposure = exposure;
 }
 
+int MajorImageProcessingThread::getRecCount()
+{
+    return m_nCount;
+}
+
 void MajorImageProcessingThread::ImageHorizontalMirror(const uint8_t* src, uint8_t* dst, int width, int height)
 {
     /*
@@ -210,7 +201,6 @@ void MajorImageProcessingThread::run()
                     emit SendFilterImageProcessing(&m_filterImg);
     //                close_v4l2_device_handler();
                 }
-
                 continue;
             }
 
@@ -227,6 +217,13 @@ void MajorImageProcessingThread::run()
 
                     yuvsize = m_nVdWidth * m_nVdHeight * 3 / 2;
                     m_yuvPtr = new uchar[yuvsize];
+                    if (m_rgbPtr != nullptr) {
+                        free(m_rgbPtr);
+                        m_rgbPtr = nullptr;
+                    }
+
+                    rgbsize = m_nVdWidth * m_nVdHeight * 3;
+                    m_rgbPtr = static_cast<uint8_t *>(calloc(rgbsize, sizeof(uint8_t)));
                 } else {
                     yuvsize = m_nVdWidth * m_nVdHeight * 3 / 2;
                 }
@@ -283,8 +280,7 @@ void MajorImageProcessingThread::run()
                 if (FFmpeg_Env == m_eEncodeEnv) {
                     // yu12到rgb数据高性能转换
                     yu12_to_rgb24_higheffic(m_rgbPtr, m_frame->yuv_frame, m_frame->width, m_frame->height);
-                }
-                else if (GStreamer_Env == m_eEncodeEnv) {
+                } else if (GStreamer_Env == m_eEncodeEnv) {
                     Q_ASSERT(m_rgbPtr);
                     memset(m_rgbPtr, 0, rgbsize * sizeof(uint8_t));
                     memcpy(m_rgbPtr, jpgImage.bits(), rgbsize);
@@ -333,6 +329,10 @@ void MajorImageProcessingThread::run()
                 if (!get_capture_pause()) {
                     //设置时间戳
                     set_video_timestamptmp(static_cast<int64_t>(m_frame->timestamp));
+                    if (m_firstPts == 0) {
+                        m_firstPts = m_frame->timestamp;
+                    }
+                    m_nCount = (m_frame->timestamp - m_firstPts) / 1000000000;
                     encoder_add_video_frame(input_frame, size, static_cast<int64_t>(m_frame->timestamp), m_frame->isKeyframe);
                 } else {
                     //设置暂停时长
@@ -371,6 +371,9 @@ void MajorImageProcessingThread::run()
             } else if (m_bRecording) {
                 // GStreamer环境下，发送rgb格式帧数据到视频写入器，完成后续视频编码任务
                 emit sigRecordFrame(m_rgbPtr, rgbsize);
+            } else {
+                m_nCount = 0;
+                m_firstPts = 0;
             }
 
             QImage* imgTmp = nullptr;
@@ -383,11 +386,36 @@ void MajorImageProcessingThread::run()
                 if (((!m_filter.isEmpty() || m_exposure) && imgTmp)
                         || GStreamer_Env == m_eEncodeEnv) {
                     if (imgTmp->save(m_strPath, "JPG")) {
+                        nRet = 0;
+                        emit sigReflushSnapshotLabel();  //
+                    }
+                } else if (FFmpeg_Env == m_eEncodeEnv) {
+                    //nRet = v4l2core_save_image(m_frame, m_strPath.toStdString().c_str(), IMG_FMT_JPG);
+
+                    uint8_t *rgbPtr = nullptr;
+                    uint nVdWidth = static_cast<unsigned int>(m_frame->width);
+                    uint nVdHeight = static_cast<unsigned int>(m_frame->height);
+
+
+                    rgbsize = nVdWidth * nVdHeight * 3;
+                    rgbPtr = static_cast<uint8_t *>(calloc(rgbsize, sizeof(uint8_t)));
+
+                    yu12_to_rgb24_higheffic(rgbPtr, m_frame->yuv_frame, m_frame->width, m_frame->height);
+                    QImage* saveImg = nullptr;
+                    if (rgbPtr)
+                        saveImg = new QImage(rgbPtr, m_frame->width, m_frame->height, QImage::Format_RGB888);
+                    if (saveImg->save(m_strPath, "JPG")) {
                         nRet = 0;
                         emit sigReflushSnapshotLabel();
                     }
-                } else if (FFmpeg_Env == m_eEncodeEnv)
-                    nRet = v4l2core_save_image(m_frame, m_strPath.toStdString().c_str(), IMG_FMT_JPG);
+                    if (saveImg)
+                        delete saveImg;
+
+                    if (rgbPtr != nullptr) {
+                        free(rgbPtr);
+                        rgbPtr = nullptr;
+                    }
+                }
 
                 if (nRet < 0) {
                     qWarning() << "保存照片失败";
