@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* Maintainer: shicetu <shicetu@uniontech.com>
-*             hujianbo <hujianbo@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "videowidget.h"
 #include "mainwindow.h"
@@ -26,6 +10,8 @@
 #include "capplication.h"
 #include "photorecordbtn.h"
 #include "camera.h"
+#include "eventlogutils.h"
+#include "config.h"
 
 #include <DBlurEffectWidget>
 
@@ -163,7 +149,7 @@ videowidget::videowidget(DWidget *parent)
     recordingwidgetlay->addWidget(m_recordingTime, 0, Qt::AlignCenter);
     recordingRedStatus->setPixmap(QPixmap(":/images/icons/light/circular.svg"));
     recordingRedStatus->setFixedSize(QSize(22, 22));
-    m_recordingTime->setFixedSize(73, 26);
+    m_recordingTime->setFixedSize(93, 26);
     m_recordingTime->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     QGraphicsDropShadowEffect *shadow_effect1 = new QGraphicsDropShadowEffect(this);
     shadow_effect1->setOffset(0, 0);              //阴影的偏移量
@@ -172,7 +158,7 @@ videowidget::videowidget(DWidget *parent)
     m_recordingTime->setGraphicsEffect(shadow_effect1);
     m_recordingTimeWidget->setLayout(recordingwidgetlay);
     m_recordingTimeWidget->hide(); //先隐藏
-    m_recordingTimeWidget->setFixedSize(95, 26);
+    m_recordingTimeWidget->setFixedSize(115, 26);
     m_dLabel->setAttribute(Qt::WA_TranslucentBackground);
     m_dLabel->setFocusPolicy(Qt::NoFocus);
     m_dLabel->setAlignment(Qt::AlignCenter);
@@ -571,14 +557,14 @@ void videowidget::showCountDownLabel(PRIVIEW_ENUM_STATE state)
 
             m_recordingTime->setText(strTime);
 
-            if ((m_nCount >= 3)) {
-                //开启多线程，每100ms读取时间并显示
+//            if ((m_nCount >= 3)) {
+//                //开启多线程，每100ms读取时间并显示
                 m_countTimer->stop();
                 m_recordingTimer->start(200);
-                return;
-            }
+//                return;
+//            }
 
-            m_nCount++;
+//            m_nCount++;
         }
         break;
 
@@ -761,13 +747,24 @@ void videowidget::showRecTime()
 {
     //获取写video的时间
     if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
-        m_nCount = static_cast<int>(get_video_time_capture());
+        /** On the equipment with poor performance, the coding time is long,
+         * which will cause 1 to 2S katto after exceeding 3S. Get recording duration.
+         *
+         * his change may lead to the short and shorter time of the video duration ratio,
+         * but this is an abnormal situation, but it should not belong to the bug.
+         *
+         * Reserved the relevant code first to prevent other unknown problems from emerging.
+         *
+         * powered by xxxxpf
+         */
+//        m_nCount = static_cast<int>(get_video_time_capture());
+        m_nCount = m_imgPrcThread->getRecCount();
 
         //过滤不正常的时间
-        if (m_nCount <= 3) {
-            qWarning() << "error time" << m_nCount;
-            return;
-        }
+//        if (m_nCount <= 3) {
+//            qWarning() << "error time" << m_nCount;
+//            return;
+//        }
     } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
         m_nCount = Camera::instance()->getRecoderTime() / 1000;
         m_nCount += 2;
@@ -943,19 +940,23 @@ void videowidget::onEndBtnClicked()
 
     QTime time;
     time.start();
+    int duration = 0;
     if (getCapStatus()) { //录制完成处理
         qDebug() << "stop takeVideo";
 
         if (DataManager::instance()->encodeEnv() == FFmpeg_Env) {
             if (video_capture_get_save_video() == 1) {
+                duration = round(get_video_time_capture());
                 set_video_time_capture(0);
                 stop_encoder_thread();
             }
         } else if (DataManager::instance()->encodeEnv() == QCamera_Env) {
             if (Camera::instance()->isRecording()) {
+                duration = Camera::instance()->getRecoderTime();
                 Camera::instance()->stopRecoder();
             }
         } else if (DataManager::instance()->encodeEnv() == GStreamer_Env) {
+            duration = m_nCount;
             if (m_audPrcThread != nullptr)
                 m_audPrcThread->stop();
             while (m_audPrcThread->isRunning());//等待音频线程结束
@@ -972,6 +973,13 @@ void videowidget::onEndBtnClicked()
 
     qInfo() << QString("-------------------stop record cost[%1]ms..----------------\n").arg(time.elapsed());
 
+    QJsonObject obj {
+        {"tid", EventLogUtils::EndRecording},
+        {"version", VERSION},
+        {"duration", duration}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
 #ifdef __sw_64__
     // 过滤停止录像编码期间的键鼠点击事件
     qApp->processEvents();
