@@ -176,6 +176,18 @@
         <source>Flashlight</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Gridlines</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1*1 lines</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2*2 lines</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Shortcut</name>
@@ -245,6 +257,14 @@
         <source>None</source>
         <translation>Nimic</translation>
     </message>
+    <message>
+        <source>mp4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>filterPreviewButton</name>
@@ -307,10 +327,6 @@
         <source>Filters</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Filters Close</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Exposure</source>
         <translation type="unfinished"></translation>
